function product = eval_prod(sq_mod,al,ind)

  % Compute (f star psi_low(j,:)) x conj(f star psi_high(j,:)) from
  % the squared modulus of (f star psi(j,:))

  % Inputs
  % sq_mod: squared modulus of (f star psi(j,:))
  % al: real number such that
  %     psi_low(j,om) = psi(j,om) * exp(-alpha*om)
  %     psi_high(j,om) = psi(j,om) * exp(alpha*om)
  % ind: regularization parameter

  % Ouput:
  % product: (f star psi_low(j,:)) x conj(f star psi_high(j,:))

  sq_mod = sq_mod(:).' ;
  N = size(sq_mod,2) ;
  oms = [[0:N/2],[-(N/2-1):-1]] ;

  ff_sq_mod = fft(sq_mod) ;

  % Calculation shows that:
  %   fft(product) = ff_sq_mod * exp(-al*oms)
  % For negative values of oms, the fact that exp(-al*oms) is very
  % large may cause numerical instabilities. Thus, it is necessary to
  % truncate oms at a certain cutoff frequency ind.
  oms_trunc = ind + abs(oms-ind) ;
  product = ifft(ff_sq_mod.*exp(-al*oms_trunc)) ;
