function [shifts1,shifts2,shifts1_inv,mul1,mul2,mul1_inv] = ...
	 modulus_app_parameters(win,psi1,psi2)

  % we need to compute the modulus of (f * win) star psi(S,:)
  % from the modulus of f star psi(S,:)
  % (and the same with S-1 instead of S)

  % for each k, we compute shifts1(k) and mul1(k) such that the linear form
  % f -> [(f * win) star psi(S,:)](k) is as close as possible to
  % f -> mul1(k) * (f star psi(S,:))(k+shifts1(k))

  % shifts2 and mul2 are defined the same way for S+1 instead of S

  % shifts1_inv, mul1_inv allow the inverse transformation
  % (reconstruct f star psi(S,:) from (f * win) star psi(S,:))

  Nw = numel(win) ; % size of the window

  % discretization of the possible choices for the values of shifts
  ds = round([-Nw/16:Nw/256:Nw/16]) ;
  % computation of shifts1 and shifts2
  psis_dec1 = [] ;
  psis_dec2 = [] ;
  for k_ds=1:numel(ds)
    psis_dec1 = [psis_dec1;psi1.*conj(circshift(psi1,[0,-ds(k_ds)]))] ;
    psis_dec2 = [psis_dec2;psi2.*conj(circshift(psi2,[0,-ds(k_ds)]))] ;
  end
  conv1 = ifft(bsxfun(@times,fft(psis_dec1,[],2),fft(win)),[],2) ;
  conv2 = ifft(bsxfun(@times,fft(psis_dec2,[],2),fft(win)),[],2) ;
  [forg,imax1] = max(abs(conv1)) ;
  [forg,imax2] = max(abs(conv2)) ;
  shifts1 = ds(imax1) ;
  shifts2 = ds(imax2) ;
  
  % slight smoothing of shifts (so that we do not introduce
  % discontinuities)
  shifts1_f = fft(shifts1) ;
  shifts2_f = fft(shifts2) ;
  ks1 = [0:floor(Nw/2),-(Nw-floor(Nw/2)-1):-1] ;
  ks2 = [0:floor(Nw/2),-(Nw-floor(Nw/2)-1):-1] ;
  shifts1 = real(ifft(shifts1_f.*exp(-ks1.^2/80))) ;
  shifts2 = real(ifft(shifts2_f.*exp(-ks2.^2/80))) ;

  % multiplicative coefficients
  mul1 = conv1(sub2ind(size(conv1),imax1,[1:Nw])) ...
         / norm(psi1,2)^2 ;
  mul2 = conv2(sub2ind(size(conv2),imax2,[1:Nw])) ...
         / norm(psi2,2)^2 ;
  % smoothing
  mul1_f = fft(mul1) ;
  mul1 = ifft(mul1_f.*exp(-ks1.^2/80)) ;
  mul2_f = fft(mul2) ;
  mul2 = ifft(mul2_f.*exp(-ks2.^2/80)) ;

  % computation of the inverse shift
  conv1_inv = ifft(bsxfun(@times,fft(psis_dec1,[],2), ...
			  fft(conj(win))),[],2) ;
  norm1 = real(ifft(fft(abs(win).^2).*fft(abs(psi1).^2))) ;
  for k_ds=1:numel(ds)
    conv1_inv(k_ds,:) = conv1_inv(k_ds,:) ./ ...
			sqrt(circshift(norm1,[0,-ds(k_ds)])) ;
  end
  [forg,imax1_inv] = max(abs(conv1_inv)) ;
  shifts1_inv = ds(imax1_inv) ;
  % smoothing
  shifts1_f = fft(shifts1_inv) ;
  shifts1_inv = real(ifft(shifts1_f.*exp(-ks1.^2/80))) ;
  
  % inverse multiplicative coefficient
  for k_ds=1:numel(ds)
    conv1_inv(k_ds,:) = conv1_inv(k_ds,:) ./ ...
			sqrt(circshift(norm1,[0,-ds(k_ds)])) ;
  end
  mul1_inv = conv1_inv(sub2ind(size(conv1_inv),imax1_inv,[1:Nw])) ;
  % smoothing
  mul1_inv_f = fft(mul1_inv) ;
  mul1_inv = ifft(mul1_inv_f.*exp(-ks1.^2/80)) ;
