function [f_out,phase] = slow_phase_mult(f_source,f_target,nlim,str)
  % this function returns f_out where, for each k:
  %    f_out[k] = f_source[k] * exp(i*alpha + 2*i*n*k/N*pi)
  % and alpha,n are chosen so that the scalar product between f_out
  % and f_target is maximal
  % (N is the size of all signals and nlim is the maximum of n in
  %  absolute value)

  % if str is defined and equal to 'not_int', then n can take non
  % integer values

  N = numel(f_target) ; % size of the signals

  if (nargin<4)
    a = 1 ; % n will be an integer
  elseif (nargin==4) && strcmp(str,'not_int')
    a = 10 ; % n will be a multiple of 1/a
  end

  % compute n
  fourier = fft(conj(f_source).*f_target,N*a) ;
  fourier([nlim*a+2:N*a-nlim*a]) = 0 ;
  [forg,n] = max(abs(fourier)) ;
  if (n<=nlim*a+1)
    n = (n-1)/a ;
  else
    n = (n-N*a-1)/a ;
  end  
  f_out = f_source .* exp(i*[0:N-1]*n/N*2*pi) ;

  % compute alpha
  alpha = angle(sum(f_target.*conj(f_out))) ;
  f_out = f_out * exp(i*alpha) ;

  % return the phase
  if (nargout>1)
     phase = exp(i*(alpha + [0:N-1]*n/N*2*pi)) ;
  end
