function [fpsi,fphi] = wavelet_transform(f,psi,phi)

  % Computes the wavelet transform of a signal

  % Inputs:
  % f: signal whose wavelet transform must be computed
  % psi: wavelets
  %      (values in the Fourier domain)
  %      (stored in an array: each wavelet is a row)
  % phi: low frequency filter (optional)
  %      (values in the Fourier domain)

  % Outputs:
  % fpsi: components of the wavelet transform
  %       (values in the time domain, stored in an array)
  % fphi: convolution of f with the low-frequency filter
    
  f = f(:).' ; % f must be a row
  if (numel(f) ~= size(psi,2))
    error(['Function wavelet_transform: the sizes of the wavelets and', ...
	   'the signal do not coincide.'])
  end
  ff = fft(f) ;

  % compute the convolution by multiplication in the Fourier domain
  fpsi = ifft(bsxfun(@times,psi,ff),[],2) ;

  % if required, compute the low frequency component
  if (nargout>1)
    if (nargin>2)
      fphi = ifft(ff.*phi) ;
    else
      error(['Function wavelet_transform: it is not possible to', ...
	     'compute the low-frequency component because no ', ...
	     'low-frequency filter has been given in input.'])
    end
  end
